package com.sooka.system.service;

import java.util.List;
import com.sooka.system.domain.TGuijiHousingconstructionZlskfrx;

/**
 * 自来水客服热线Service接口
 * 
 * @author lei
 * @date 2021-11-05
 */
public interface ITGuijiHousingconstructionZlskfrxService 
{
    /**
     * 查询自来水客服热线
     * 
     * @param id 自来水客服热线ID
     * @return 自来水客服热线
     */
    public TGuijiHousingconstructionZlskfrx selectTGuijiHousingconstructionZlskfrxById(String id);

    /**
     * 查询自来水客服热线列表
     * 
     * @param tGuijiHousingconstructionZlskfrx 自来水客服热线
     * @return 自来水客服热线集合
     */
    public List<TGuijiHousingconstructionZlskfrx> selectTGuijiHousingconstructionZlskfrxList(TGuijiHousingconstructionZlskfrx tGuijiHousingconstructionZlskfrx);

    /**
     * 新增自来水客服热线
     * 
     * @param tGuijiHousingconstructionZlskfrx 自来水客服热线
     * @return 结果
     */
    public int insertTGuijiHousingconstructionZlskfrx(TGuijiHousingconstructionZlskfrx tGuijiHousingconstructionZlskfrx);

    /**
     * 修改自来水客服热线
     * 
     * @param tGuijiHousingconstructionZlskfrx 自来水客服热线
     * @return 结果
     */
    public int updateTGuijiHousingconstructionZlskfrx(TGuijiHousingconstructionZlskfrx tGuijiHousingconstructionZlskfrx);

    /**
     * 批量删除自来水客服热线
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTGuijiHousingconstructionZlskfrxByIds(String ids);

    /**
     * 删除自来水客服热线信息
     * 
     * @param id 自来水客服热线ID
     * @return 结果
     */
    public int deleteTGuijiHousingconstructionZlskfrxById(String id);
}
